From 2d9ee293fe2d0ab4dd7604b1c8628479a983fa66 Mon Sep 17 00:00:00 2001
From: Amul Sul <amul.sul@enterprisedb.com>
Date: Wed, 14 Dec 2022 11:52:24 +0530
Subject: [PATCH v1 21/25] Change point_in to allow non-throw error reporting

---
 src/backend/utils/adt/geo_ops.c     |  2 +-
 src/test/regress/expected/point.out | 13 +++++++++++++
 src/test/regress/sql/point.sql      |  4 ++++
 3 files changed, 18 insertions(+), 1 deletion(-)

diff --git a/src/backend/utils/adt/geo_ops.c b/src/backend/utils/adt/geo_ops.c
index 792ae790114..cfd4424f756 100644
--- a/src/backend/utils/adt/geo_ops.c
+++ b/src/backend/utils/adt/geo_ops.c
@@ -1837,7 +1837,7 @@ point_in(PG_FUNCTION_ARGS)
 	char	   *str = PG_GETARG_CSTRING(0);
 	Point	   *point = (Point *) palloc(sizeof(Point));
 
-	pair_decode(str, &point->x, &point->y, NULL, "point", str, NULL);
+	pair_decode(str, &point->x, &point->y, NULL, "point", str, fcinfo->context);
 	PG_RETURN_POINT_P(point);
 }
 
diff --git a/src/test/regress/expected/point.out b/src/test/regress/expected/point.out
index 3bde8ac7d09..a716ceb881b 100644
--- a/src/test/regress/expected/point.out
+++ b/src/test/regress/expected/point.out
@@ -463,3 +463,16 @@ SELECT COUNT(*) FROM point_gist_tbl WHERE f1 ~= '(0.0000018,0.0000018)'::point;
 RESET enable_seqscan;
 RESET enable_indexscan;
 RESET enable_bitmapscan;
+-- test non-error-throwing API for some core types
+SELECT pg_input_is_valid('1,y', 'point');
+ pg_input_is_valid 
+-------------------
+ f
+(1 row)
+
+SELECT pg_input_error_message('1,y', 'point');
+           pg_input_error_message           
+--------------------------------------------
+ invalid input syntax for type point: "1,y"
+(1 row)
+
diff --git a/src/test/regress/sql/point.sql b/src/test/regress/sql/point.sql
index 435ff4b9b69..7bd1ebe2b51 100644
--- a/src/test/regress/sql/point.sql
+++ b/src/test/regress/sql/point.sql
@@ -96,3 +96,7 @@ SELECT COUNT(*) FROM point_gist_tbl WHERE f1 ~= '(0.0000018,0.0000018)'::point;
 RESET enable_seqscan;
 RESET enable_indexscan;
 RESET enable_bitmapscan;
+
+-- test non-error-throwing API for some core types
+SELECT pg_input_is_valid('1,y', 'point');
+SELECT pg_input_error_message('1,y', 'point');
-- 
2.18.0

